==========================
Generic linking for Django
==========================

.. image:: https://badge.fury.io/py/django-anylink.png
    :target: http://badge.fury.io/py/django-anylink
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/moccu/django-anylink.png
   :target: https://travis-ci.org/moccu/django-anylink
   :alt: Latest Travis CI build status

.. image:: https://coveralls.io/repos/moccu/django-anylink/badge.svg
  :target: https://coveralls.io/github/moccu/django-anylink
  :alt: Coverage of master build

.. image:: https://readthedocs.org/projects/django-anylink/badge/?version=latest
    :target: https://readthedocs.org/projects/django-anylink/?badge=latest
    :alt: Latest read the docs build


`django-anylink` is a generic linking module for Django. Using this module, you
can create links for many usecases.


Installation & Documentation
----------------------------

You can find all documentation in the "docs/source" folder and online at
All documentation is in the "docs/source" directory and online at
`Read the Docs <https://readthedocs.org/projects/django-anylink/>`_.


License
-------

*django-anylink* is licenced under the BSD License (see LICENSE).


Resources
---------

* `Documentation <https://readthedocs.org/projects/django-anylink/>`_
* `Bug Tracker <https://github.com/moccu/django-anylink/issues/>`_
* `Code <https://github.com/moccu/django-anylink>`_
